==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/DescribeTrafficMirrorSessionsRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{
  NextToken,
  TrafficMirroringMaxResults,
  TrafficMirrorSessionId
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeTrafficMirrorSessionsRequest(
    trafficMirrorSessionIds: Optional[Iterable[TrafficMirrorSessionId]] =
      Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[TrafficMirroringMaxResults] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest = {
    import DescribeTrafficMirrorSessionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest
      .builder()
      .optionallyWith(
        trafficMirrorSessionIds.map(value =>
          value.map { item =>
            TrafficMirrorSessionId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.trafficMirrorSessionIds)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value =>
          TrafficMirroringMaxResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest.wrap(buildAwsValue())
}
object DescribeTrafficMirrorSessionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest =
      zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest(
        trafficMirrorSessionIds.map(value => value),
        dryRun.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def trafficMirrorSessionIds: Optional[List[TrafficMirrorSessionId]]
    def dryRun: Optional[Boolean]
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[TrafficMirroringMaxResults]
    def nextToken: Optional[NextToken]
    def getTrafficMirrorSessionIds
        : ZIO[Any, AwsError, List[TrafficMirrorSessionId]] = AwsError
      .unwrapOptionField("trafficMirrorSessionIds", trafficMirrorSessionIds)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, TrafficMirroringMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest
  ) extends zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest.ReadOnly {
    override val trafficMirrorSessionIds
        : Optional[List[TrafficMirrorSessionId]] = zio.aws.core.internal
      .optionalFromNullable(impl.trafficMirrorSessionIds())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.primitives.TrafficMirrorSessionId(item)
        }.toList
      )
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[TrafficMirroringMaxResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ec2.model.primitives.TrafficMirroringMaxResults(value)
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ec2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest
  ): zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.126.1-sources.jar: zio/aws/ec2/model/DescribeTrafficMirrorSessionsRequest.scala <==
package zio.aws.ec2.model
import java.lang.Integer
import zio.aws.ec2.model.primitives.{
  NextToken,
  TrafficMirroringMaxResults,
  TrafficMirrorSessionId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeTrafficMirrorSessionsRequest(
    trafficMirrorSessionIds: Option[Iterable[TrafficMirrorSessionId]] = None,
    filters: Option[Iterable[zio.aws.ec2.model.Filter]] = None,
    maxResults: Option[TrafficMirroringMaxResults] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest = {
    import DescribeTrafficMirrorSessionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest
      .builder()
      .optionallyWith(
        trafficMirrorSessionIds.map(value =>
          value.map { item =>
            TrafficMirrorSessionId.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.trafficMirrorSessionIds)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value =>
          TrafficMirroringMaxResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest.wrap(buildAwsValue())
}
object DescribeTrafficMirrorSessionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest =
      zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest(
        trafficMirrorSessionIds.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def trafficMirrorSessionIds: Option[List[TrafficMirrorSessionId]]
    def filters: Option[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Option[TrafficMirroringMaxResults]
    def nextToken: Option[NextToken]
    def getTrafficMirrorSessionIds
        : ZIO[Any, AwsError, List[TrafficMirrorSessionId]] = AwsError
      .unwrapOptionField("trafficMirrorSessionIds", trafficMirrorSessionIds)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, TrafficMirroringMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest
  ) extends zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest.ReadOnly {
    override val trafficMirrorSessionIds: Option[List[TrafficMirrorSessionId]] =
      scala
        .Option(impl.trafficMirrorSessionIds())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.primitives.TrafficMirrorSessionId(item)
          }.toList
        )
    override val filters: Option[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      scala
        .Option(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Option[TrafficMirroringMaxResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.ec2.model.primitives.TrafficMirroringMaxResults(value)
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.ec2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeTrafficMirrorSessionsRequest
  ): zio.aws.ec2.model.DescribeTrafficMirrorSessionsRequest.ReadOnly =
    new Wrapper(impl)
}
